@@ -13,9 +13,11 @@ except ImportError:  # Python2
 from .pointvector import Point2D, Vector2D
 from .line import LineSegment2D
 from .ray import Ray2D
+from ..triangulation import _linked_list, _eliminate_holes
 from ..intersection2d import intersect_line2d, intersect_line2d_infinite, \
     does_intersection_exist_line2d, closest_point2d_on_line2d
 from ._2d import Base2DIn2D
+import ladybug_geometry.boolean as pb
 
 inf = float("inf")
 
@@ -233,6 +235,58 @@ class Polygon2D(Base2DIn2D):
         _new_poly._is_self_intersecting = False
         return _new_poly
 
+    @classmethod
+    def from_shape_with_holes_fast(cls, boundary, holes):
+        """Initialize a Polygon2D from a boundary shape with holes using a fast method.
+
+        This method is similar in principle to the from_shape_with_holes method
+        but it uses David Eberly's algorithm for finding a bridge between the holes
+        and outer polygon. This is extremely fast in comparison to the methods used
+        by from_shape_with_holes but is not always the prettiest or the shortest
+        pathway through the holes. Granted, it is very practical for shapes with
+        lots of holes (eg. 100 holes) and will run in a fraction of the time for
+        this case.
+
+        Args:
+            boundary: A list of Point2D objects for the outer boundary of the polygon
+                inside of which all of the holes are contained.
+            holes: A list of lists with one list for each hole in the shape. Each hole
+                should be a list of at least 3 Point2D objects.
+        """
+        # check the initial direction of the boundary vertices
+        bound_direction = cls._are_clockwise(boundary)
+        # format the coordinates for input to the earcut methods
+        vert_coords, hole_indices = [], None
+        for pt in boundary:
+            vert_coords.append(pt.x)
+            vert_coords.append(pt.y)
+        hole_indices = []
+        for hole in holes:
+            hole_indices.append(int(len(vert_coords) / 2))
+            for pt in hole:
+                vert_coords.append(pt.x)
+                vert_coords.append(pt.y)
+
+        # eliminate the holes within the list
+        outer_len = hole_indices[0] * 2
+        outer_node = _linked_list(vert_coords, 0, outer_len, 2, True)
+        outer_node = _eliminate_holes(vert_coords, hole_indices, outer_node, 2)
+
+        # loop through the chain of nodes and translate them to Point2D
+        start_i = outer_node.i
+        vertices = [Point2D(outer_node.x, outer_node.y)]
+        node = outer_node.next
+        while node.i != start_i:
+            vertices.append(Point2D(node.x, node.y))
+            node = node.next
+
+        # return the polygon with some properties set based on what we know
+        _new_poly = cls(vertices)
+        _new_poly._is_clockwise = bound_direction
+        _new_poly._is_convex = False
+        _new_poly._is_self_intersecting = False
+        return _new_poly
+
     @property
     def vertices(self):
         """Tuple of all vertices in this geometry."""
@@ -904,6 +958,209 @@ class Polygon2D(Base2DIn2D):
         """Get a list of lists where each sub-list represents a Point2D vertex."""
         return tuple(pt.to_array() for pt in self.vertices)
 
+    def _to_bool_poly(self):
+        """A hidden method used to translate the Polygon2D to a BooleanPolygon.
+
+        This is necessary before performing any boolean operations with
+        the polygon.
+        """
+        b_pts = (pb.BooleanPoint(pt.x, pt.y) for pt in self.vertices)
+        return pb.BooleanPolygon([b_pts])
+
+    @staticmethod
+    def _from_bool_poly(bool_polygon):
+        """Get a list of Polygon2D from a BooleanPolygon object."""
+        return [Polygon2D(tuple(Point2D(pt.x, pt.y) for pt in new_poly))
+                for new_poly in bool_polygon.regions]
+
+    def boolean_union(self, polygon, tolerance):
+        """Get a list of Polygon2D for the union of this Polygon and another.
+
+        Note that the result will not differentiate hole polygons from boundary
+        polygons and so it may be desirable to use the Polygon2D.is_polygon_inside
+        method to distinguish whether a given polygon in the result represents
+        a hole in another polygon in the result.
+
+        Also note that this method will return the original polygons when there
+        is no overlap in the two.
+
+        Args:
+            polygon: A Polygon2D for which the union with the current polygon
+                will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the union of the two polygons.
+        """
+        result = pb.union(
+            self._to_bool_poly(), polygon._to_bool_poly(), tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    def boolean_intersect(self, polygon, tolerance):
+        """Get a list of Polygon2D for the intersection of this Polygon and another.
+
+        Args:
+            polygon: A Polygon2D for which the intersection with the current polygon
+                will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the intersection of the two polygons.
+            Will be an empty list if no overlap exists between the polygons.
+        """
+        result = pb.intersect(
+            self._to_bool_poly(), polygon._to_bool_poly(), tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    def boolean_difference(self, polygon, tolerance):
+        """Get a list of Polygon2D for the subtraction of another polygon from this one.
+
+        Args:
+            polygon: A Polygon2D for which the difference with the current polygon
+                will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the difference of the two polygons.
+            Will be an empty list if subtracting the polygons results in the complete
+            elimination of this polygon. Will be the original polygon when there
+            is no overlap between the polygons.
+        """
+        result = pb.difference(
+            self._to_bool_poly(), polygon._to_bool_poly(), tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    def boolean_xor(self, polygon, tolerance):
+        """Get Polygon2D list for the exclusive disjunction of this polygon and another.
+
+        Note that this method is prone to merging holes that may exist in the
+        result into the boundary to create a single list of joined vertices,
+        which may not always be desirable. In this case, it may be desirable
+        to do two separate boolean_difference calculations instead.
+
+        Also note that, when the result includes separate polygons for holes,
+        it will not differentiate hole polygons from boundary polygons
+        and so it may be desirable to use the Polygon2D.is_polygon_inside
+        method to distinguish whether a given polygon in the result represents
+        a hole within another polygon in the result.
+
+        Args:
+            polygon: A Polygon2D for which the exclusive disjunction with the
+                current polygon will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the exclusive disjunction of the
+            two polygons. Will be the original polygons when there is no overlap
+            in the two.
+        """
+        result = pb.xor(
+            self._to_bool_poly(), polygon._to_bool_poly(), tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    @staticmethod
+    def boolean_union_all(polygons, tolerance):
+        """Get a list of Polygon2D for the union of several Polygon2D.
+
+        Using this method is more computationally efficient than calling the
+        Polygon2D.boolean_union() method multiple times as this method will 
+        only compute the intersection of the segments once.
+
+        Note that the result will not differentiate hole polygons from boundary
+        polygons and so it may be desirable to use the Polygon2D.is_polygon_inside
+        method to distinguish whether a given polygon in the result represents
+        a hole in another polygon in the result.
+
+        Also note that this method will return the original polygons when there
+        is no overlap in the two.
+
+        Args:
+            polygons: An array of Polygon2D for which the union will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the union of all the polygons.
+        """
+        bool_polys = [poly._to_bool_poly() for poly in polygons]
+        result = pb.union_all(bool_polys, tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    @staticmethod
+    def boolean_intersect_all(polygons, tolerance):
+        """Get a list of Polygon2D for the intersection of several Polygon2D.
+
+        Using this method is more computationally efficient than calling the
+        Polygon2D.boolean_intersect() method multiple times as this method will 
+        only compute the intersection of the segments once.
+
+        Note that the result will not differentiate hole polygons from boundary
+        polygons and so it may be desirable to use the Polygon2D.is_polygon_inside
+        method to distinguish whether a given polygon in the result represents
+        a hole in another polygon in the result.
+
+        Also note that this method will return the original polygons when there
+        is no overlap in the two.
+
+        Args:
+            polygons: An array of Polygon2D for which the intersection will be computed.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A list of Polygon2D representing the intersection of all the polygons.
+            Will be an empty list if no overlap exists between the polygons.
+        """
+        bool_polys = [poly._to_bool_poly() for poly in polygons]
+        result = pb.intersect_all(bool_polys, tolerance)
+        return Polygon2D._from_bool_poly(result)
+
+    @staticmethod
+    def boolean_split(polygon1, polygon2, tolerance):
+        """Split two Polygon2D with one another to get the intersection and difference.
+
+        Using this method is more computationally efficient than calling the
+        Polygon2D.intersect() and Polygon2D.difference() methods individually as
+        this method will only compute the intersection of the segments once.
+
+        Note that the result will not differentiate hole polygons from boundary
+        polygons and so it may be desirable to use the Polygon2D.is_polygon_inside
+        method to distinguish whether a given polygon in the result represents
+        a hole in another polygon in the result.
+
+        Args:
+            polygon1: A Polygon2D for the first polygon that will be split with
+                the second polygon.
+            polygon2: A Polygon2D for the second polygon that will be split with
+                the first polygon.
+            tolerance: The minimum distance between points before they are
+                considered distinct from one another.
+
+        Returns:
+            A tuple with three elements
+
+        -   intersection: A list of Polygon2D for the intersection of the two
+            input polygons.
+
+        -   poly1_difference: A list of Polygon2D for the portion of polygon1 that does
+            not overlap with polygon2. When combined with the intersection, this
+            makes a split version of polygon1.
+
+        -   poly2_difference: A list of Polygon2D for the portion of polygon2 that does
+            not overlap with polygon1. When combined with the intersection, this
+            makes a split version of polygon2.
+        """
+        int_result, poly1_result, poly2_result = pb.split(
+            polygon1._to_bool_poly(), polygon2._to_bool_poly(), tolerance)
+        intersection = Polygon2D._from_bool_poly(int_result)
+        poly1_difference = Polygon2D._from_bool_poly(poly1_result)
+        poly2_difference = Polygon2D._from_bool_poly(poly2_result)
+        return intersection, poly1_difference, poly2_difference
+
     @staticmethod
     def intersect_polygon_segments(polygon_list, tolerance):
         """Intersect the line segments of a Polygon2D array to ensure matching segments.
@@ -987,9 +1244,9 @@ class Polygon2D(Base2DIn2D):
         """Check if the bounding rectangles of two polygons overlap within a tolerance.
 
         This is particularly useful as a check before performing computationally intense
-        processes between two polygons like intersection or checking for adjacency.
-        Checking the overlap of the bounding boxes is extremely quick given this
-        method's use of the Separating Axis Theorem.
+        processes between two polygons like intersection or boolean operations.
+        Checking the overlap of the bounding boxes is extremely quick with this
+        method's use of the the Separating Axis Theorem.
 
         Args:
             polygon1: The first polygon to check.
