@@ -1,5 +1,8 @@
 # coding=utf-8
-"""Utility functions for computing intersections between geometry in 2D space."""
+"""Utility functions for computing intersections between geometry in 2D space.
+
+Taken mostly from the euclid.py package.
+"""
 from __future__ import division
 
 from .geometry2d.pointvector import Point2D, Vector2D
@@ -16,7 +19,7 @@ def intersect_line2d(line_ray_a, line_ray_b):
 
     The derivation of ua is achieved by crossing both sides of the above equation
     with the direction vector of B, and rearranging the formula:
-    
+
     .. code-block:: python
 
         A.p + ua * A.v = B.p + ub * B.v
