@@ -18,6 +18,8 @@ def test_linesegment2_init():
     assert seg.v == Vector2D(0, 2)
     assert seg.p1 == Point2D(2, 0)
     assert seg.p2 == Point2D(2, 2)
+    assert seg.min == Point2D(2, 0)
+    assert seg.max == Point2D(2, 2)
     assert seg.midpoint == Point2D(2, 1)
     assert seg.point_at(0.25) == Point2D(2, 0.5)
     assert seg.point_at_length(1) == Point2D(2, 1)
@@ -124,7 +126,7 @@ def test_equivalent():
         Point2D(2.001, 3.00), Vector2D(-1.5, -2.5))
     assert not seg1.is_equivalent(seg2, 1e-10)
 
-     # Test not equal second point
+    # Test not equal second point
     seg2 = LineSegment2D(
         Point2D(0.5001, 0.5), Vector2D(1.5, 2.5))
     assert not seg1.is_equivalent(seg2, 1e-10)
@@ -187,7 +189,7 @@ def test_rotate():
     assert test_1.v.x == pytest.approx(0, rel=1e-3)
     assert test_1.v.y == pytest.approx(-2, rel=1e-3)
 
-    test_2 = seg.rotate(math.pi/2, origin_1)
+    test_2 = seg.rotate(math.pi / 2, origin_1)
     assert test_2.p.x == pytest.approx(0, rel=1e-3)
     assert test_2.p.y == pytest.approx(4, rel=1e-3)
     assert test_2.v.x == pytest.approx(-2, rel=1e-3)
